@@ -14,14 +14,8 @@
 #  You should have received a copy of the GNU General Public License
 #  along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
-try:
-    from notes.boostnote import BoostNote
-    from notes.simplenote import SimpleNote
-except (ImportError, ModuleNotFoundError):
-    import sys
-    sys.path.append(sys.path[0] + '/..')
-    from notes.boostnote import BoostNote
-    from notes.simplenote import SimpleNote
+from boost2simple.notes.boostnote import BoostNote
+from boost2simple.notes.simplenote import SimpleNote
 
 
 class Converter:
