@@ -21,13 +21,7 @@ from ctypes import windll
 from tkinter.filedialog import askdirectory
 from tkinter.font import Font
 
-try:
-    from boost2simple import converter
-except (ImportError, ModuleNotFoundError):
-    import sys
-    sys.path.append(sys.path[0] + '/..')
-    from boost2simple import converter
-
+from boost2simple import converter
 
 primary_light = "#F7F7FF"
 primary_dark = "#545E75"
