@@ -22,12 +22,7 @@ import os
 
 import scandir
 
-try:
-    from boost2simple import util
-except (ImportError, ModuleNotFoundError):
-    import sys
-    sys.path.append(sys.path[0] + '/..')
-    from boost2simple import util
+from boost2simple import util
 
 
 class BoostNote:
