@@ -21,16 +21,9 @@ import os
 import uuid
 import zipfile
 from io import BytesIO
-from typing import Union
 
-try:
-    from boost2simple import util
-    from boost2simple.notes.boostnote import BoostNote
-except (ImportError, ModuleNotFoundError):
-    import sys
-    sys.path.append(sys.path[0] + '/..')
-    from boost2simple import util
-    from boost2simple.notes.boostnote import BoostNote
+from boost2simple import util
+from boost2simple.notes.boostnote import BoostNote
 
 
 class SimpleNote:
@@ -183,11 +176,7 @@ class SimpleNote:
 
         def export_zip(self,
                        filename: str = "notes.zip",
-                       target_dir: Union[int,
-                                         str,
-                                         bytes,
-                                         os.PathLike
-                                         ] = ""):
+                       target_dir = ""):
 
             archive: BytesIO = self._to_zip_bytestream()
             cwd = os.getcwd()
